==> 0.0.1%2B1.tar.gz: lib/models/IR5Staff.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'IR5Staff.g.dart';

// --------------------------------------------------------------------------------
enum StaffLevel { Staff, Manager, Boss, Commis, OnlyClock }
const Map<int, StaffLevel> StaffLevels = {
  0: StaffLevel.Staff,
  1: StaffLevel.Manager,
  2: StaffLevel.Boss,
  3: StaffLevel.Commis,
  4: StaffLevel.OnlyClock,
};
int StaffLevelToJson(StaffLevel f) {
  return StaffLevels.entries.firstWhere((element) => element.value == f).key;
}
// --------------------------------------------------------------------------------

/** PERSO aka Staffs */
@JsonSerializable()
class IR5Staff {
  const IR5Staff({
    required this.Nom,
    required this.No,
    required this.Level,
    required this.NISS,
    required this.UserLogin,
    required this.Description,
    required this.Language,
    required this.Color,
    required this.Actif,
    required this.Flags,
    required this.PointageFlags,
    required this.BOFlags,
    required this.OLAPFlags,
    required this.RptFlags,
    required this.MemberFlags,
    required this.TblModePOS,
    required this.LayoutRptOuv,
    required this.Divisions,
    required this.Stations,
    required this.Onglets,
    required this.StaffIN,
    required this.StaffOUT,
    required this.ClockIN,
    required this.ClockOUT,
    required this.SaldoOuv,
    required this.ConsoOuv,
    required this.CvtsOuv,
    required this.LstSalle,
    required this.StaffLevel,
  });

  factory IR5Staff.fromJson(Map<String, dynamic>? json) => _$IR5StaffFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5StaffToJson(this);

  /** Staff Name */
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num No;
  @JsonKey(defaultValue: 0)
  final int /* Number | StaffLevel */ Level;

  /** Staff NISS
   * Social Security Identification Number
   * It is most of the time the National Registry Number
   */
  @JsonKey(defaultValue: '')
  final String NISS;

  /** MyRestomax User Login Name */
  @JsonKey(defaultValue: '')
  final String UserLogin;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Language Index :
   * 0 : French (Default)
   * 1 : Dutch
   * 2 : English
   * 3 : German
   * 4 : Spanish
   */
  @JsonKey(defaultValue: 0)
  final num Language;

  /** Staff personnal color. Easier to identify which Staff is logged in */
  @JsonKey(defaultValue: '')
  final String Color;
  @JsonKey(defaultValue: false)
  final bool Actif;

  /** Staff Flags
   *   Bit 00 : NotBlocked
   *   Bit 01 : OnlyViaBadge
   *   Bit 02 : RemoteAccess
   *   Bit 03 : OnlyViaTelemax
   *   Bit 04 : ForceBackHome
   *   Bit 05 : CanChgSalle
   *   Bit 06 : GotoFirstOnglet
   *   Bit 07 : StayInAccueil
   *   Bit 08 : AllLastSalle
   *   Bit 09 : ModePOS
   *   Bit 10 : Manager
   *   Bit 11 : SuperStaffAutomatic
   *   Bit 12 : ManagerPasDeCaisse
   *   Bit 13 : StudentUseTeacherOnlyDivisions
   *   Bit 14 : StudentUseTeacherOnlyStations
   *   Bit 15 : StudentUseTeacherOnlyOnglets
   *   Bit 16 : GotoLastTbl
   *   Bit 17 : OpenStaff_DoNotPrintRpt
   *   Bit 20 : OpenService
   *   Bit 21 : OpenService_NoDteControl
   *   Bit 24 : ClotureService
   *   Bit 25 : ClotureService_WithOpenTable
   *   Bit 26 : ClotureService_PrintRpt
   *   Bit 30 : ClotureStaff
   *   Bit 31 : ClotureStaff_WithOpenTable
   *   Bit 32 : ClotureStaff_DoNotPrintRpt
   *   Bit 33 : ClotureStaff_DoNotKeepPrestation
   *   Bit 34 : ReOpenStaff
   *   Bit 40 : Visu
   *   Bit 41 : VisuTjsFiltree
   *   Bit 42 : VisuSansTotaux
   *   Bit 43 : VisuRptXorZ
   *   Bit 44 : VisuShowDate
   *   Bit 50 : ModifBlocage
   *   Bit 51 : ModifStock
   *   Bit 52 : WebView
   *   Bit 60 : Boss
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Staff Pointage Flags
   *   Bit 01 : CanPrintFullTicket
   *   Bit 02 : CanPointer
   *   Bit 03 : NoBtnError
   *   Bit 04 : AnnuleArticle
   *   Bit 05 : AnnuleControlee
   *   Bit 06 : ShowBtnRemise
   *   Bit 07 : ShowBtnChgPrix
   *   Bit 08 : ShowBtnOffert
   *   Bit 09 : CanToggleInOut
   *   Bit 10 : Training
   *   Bit 11 : ForceTraining
   *   Bit 12 : OnlyTraining
   *   Bit 15 : CanToggleTariff
   *   Bit 20 : CanAddition
   *   Bit 21 : RedoAddition
   *   Bit 22 : CanPointerAfterAdd
   *   Bit 23 : ParamAddition
   *   Bit 30 : CanCash
   *   Bit 31 : ManualCashDrawer
   *   Bit 32 : NoCashDrawer
   *   Bit 33 : NoAutoCashDrawer
   *   Bit 34 : NoAutoCashDrawerIfConso
   *   Bit 35 : CanSplitMontant
   *   Bit 36 : NoNegatifOnMachine
   *   Bit 40 : Split
   *   Bit 41 : SplitAfterAddition
   *   Bit 51 : TftAfterAddition
   */
  @JsonKey(defaultValue: 0)
  final num PointageFlags;

  /** Staff Backoffice Flags
   *   Bit 10 : EditStaff
   *   Bit 11 : EditStaffLimited
   *   Bit 13 : EditStaffSuperLimited
   *   Bit 14 : EditStaffViewAll
   *   Bit 20 : EditMsgAccueil
   *   Bit 21 : EditPlanSalle
   *   Bit 22 : EditCarte
   *   Bit 23 : EditModePayement
   *   Bit 24 : EditImprimantes
   *   Bit 25 : EditImages
   *   Bit 40 : EditEvenement
   *   Bit 41 : EditReservation
   *   Bit 63 : EditOthers
   */
  @JsonKey(defaultValue: 0)
  final num BOFlags;

  /** Staff Olap Flags
   *   Bit 10 : DTSOps
   *   Bit 11 : DTS_NoArchives
   *   Bit 12 : DTS_NoDBOps
   *   Bit 13 : DTS_NoExportImportOps
   *   Bit 20 : SQLEditor
   *   Bit 21 : SQLBtns
   *   Bit 28 : Tools
   *   Bit 34 : DuplicataAdd
   *   Bit 35 : TicketSimple
   *   Bit 36 : RefundTicket
   *   Bit 40 : AccLink
   *   Bit 41 : AccLinkParams
   *   Bit 50 : Billing
   */
  @JsonKey(defaultValue: 0)
  final num OLAPFlags;

  /** Staff Report Flags
   *   Bit 01 : RptPrint
   *   Bit 02 : RptFiltered
   *   Bit 10 : RptStatis
   *   Bit 11 : RptListeReassor
   *   Bit 12 : RptTablesOuvertes
   *   Bit 13 : RptCustom1
   *   Bit 16 : RptStaffOuverts
   *   Bit 17 : RptCustom2
   *   Bit 19 : RptRptJournee
   *   Bit 21 : RptCustom3
   *   Bit 22 : RptTaxRate
   *   Bit 23 : RptDetailsModif
   *   Bit 25 : RptCustom4
   *   Bit 26 : RptFR3SummaryView
   *   Bit 27 : RptPointages
   *   Bit 29 : RptCustom5
   *   Bit 30 : RptFR3Renta
   *   Bit 31 : RptRecettes
   *   Bit 32 : RptDuplicClotureStaff
   *   Bit 33 : RptCustom6
   *   Bit 34 : RptFR3DailyView
   *   Bit 35 : RptAdditions
   *   Bit 36 : RptDuplicClotureService
   *   Bit 37 : RptVerifTVA
   *   Bit 38 : RptExtRpts
   *   Bit 39 : RptAdditionsDet
   *   Bit 40 : RptSrvcZ
   *   Bit 41 : RptAll
   *   Bit 50 : RptExtRptsEdit
   */
  @JsonKey(defaultValue: 0)
  final num RptFlags;

  /** Staff Report Flags
   *   Bit 00 : MemberCreation
   *   Bit 01 : MemberDelete
   *   Bit 02 : MemberModif
   *   Bit 10 : MemberModifTVA
   *   Bit 11 : MemberModifCreditLimit
   *   Bit 13 : MemberModifDiscount
   *   Bit 14 : MemberModifAddress
   *   Bit 15 : MemberModifContact
   *   Bit 16 : MemberModifMemo
   *   Bit 30 : MemberVoirTVA
   *   Bit 31 : MemberVoirCreditLimit
   *   Bit 33 : MemberVoirDiscount
   *   Bit 34 : MemberVoirAddress
   *   Bit 35 : MemberVoirContact
   *   Bit 36 : MemberVoirMemo
   *   Bit 40 : MemberShowBtn
   *   Bit 41 : MemberNoSelect
   *   Bit 42 : MemberSelectOnlyBarcode
   *   Bit 50 : MemberEncaisseSurCpte
   *   Bit 51 : MemberRechargeCpte
   *   Bit 52 : MemberCaution
   *   Bit 53 : MemberEncaisseSurCpteLimited
   *   Bit 58 : MemberSoloCloture
   */
  @JsonKey(defaultValue: 0)
  final num MemberFlags;
  @JsonKey(defaultValue: '')
  final String TblModePOS;

  /** Print Layout */
  @JsonKey(defaultValue: 0)
  final num LayoutRptOuv;

  /** Accessible Division(s) for the Station,Staff,Article,.. */
  @JsonKey(defaultValue: '')
  final String Divisions;

  /** Accessible Station(s) for the Staff,Article,.. */
  @JsonKey(defaultValue: '')
  final String Stations;

  /** Visible Tab(s) for the Station,Staff,... */
  @JsonKey(defaultValue: '')
  final String Onglets;
  @JsonKey(defaultValue: '')
  final String StaffIN;
  @JsonKey(defaultValue: '')
  final String StaffOUT;
  @JsonKey(defaultValue: '')
  final String ClockIN;
  @JsonKey(defaultValue: '')
  final String ClockOUT;
  @JsonKey(defaultValue: 0)
  final num SaldoOuv;
  @JsonKey(defaultValue: 0)
  final num ConsoOuv;
  @JsonKey(defaultValue: 0)
  final num CvtsOuv;
  @JsonKey(defaultValue: '')
  final String LstSalle;

  /**
   *
   * Mix Flags and PointageFlags [sfOnlyClockInOut,sfCommis,sfManager,sfBoss]   */
  @JsonKey(defaultValue: 0)
  final int StaffLevel;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5Staff.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'IR5Staff.g.dart';

// --------------------------------------------------------------------------------
enum StaffLevel { Staff, Manager, Boss, Commis, OnlyClock }
const Map<int, StaffLevel> StaffLevels = {
  0: StaffLevel.Staff,
  1: StaffLevel.Manager,
  2: StaffLevel.Boss,
  3: StaffLevel.Commis,
  4: StaffLevel.OnlyClock,
};
int StaffLevelToJson(StaffLevel f) {
  return StaffLevels.entries.firstWhere((element) => element.value == f).key;
}
// --------------------------------------------------------------------------------

/** PERSO aka Staffs */
@JsonSerializable()
class IR5Staff {
  const IR5Staff({
    required this.Nom,
    required this.No,
    required this.Level,
    required this.NISS,
    required this.UserLogin,
    required this.Description,
    required this.Language,
    required this.Color,
    required this.Actif,
    required this.Flags,
    required this.PointageFlags,
    required this.BOFlags,
    required this.OLAPFlags,
    required this.RptFlags,
    required this.MemberFlags,
    required this.TblModePOS,
    required this.LayoutRptOuv,
    required this.Divisions,
    required this.Stations,
    required this.Onglets,
    required this.StaffIN,
    required this.StaffOUT,
    required this.ClockIN,
    required this.ClockOUT,
    required this.SaldoOuv,
    required this.ConsoOuv,
    required this.CvtsOuv,
    required this.LstSalle,
    required this.StaffLevel,
  });

  factory IR5Staff.fromJson(Map<String, dynamic>? json) =>
      _$IR5StaffFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5StaffToJson(this);

  /** Staff Name */
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num No;
  @JsonKey(defaultValue: 0)
  final int /* Number | StaffLevel */ Level;

  /** Staff NISS
   * Social Security Identification Number
   * It is most of the time the National Registry Number
   */
  @JsonKey(defaultValue: '')
  final String NISS;

  /** MyRestomax User Login Name */
  @JsonKey(defaultValue: '')
  final String UserLogin;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Language Index :
   * 0 : French (Default)
   * 1 : Dutch
   * 2 : English
   * 3 : German
   * 4 : Spanish
   */
  @JsonKey(defaultValue: 0)
  final num Language;

  /** Staff personnal color. Easier to identify which Staff is logged in */
  @JsonKey(defaultValue: '')
  final String Color;
  @JsonKey(defaultValue: false)
  final bool Actif;

  /** Staff Flags
   *   Bit 00 : NotBlocked
   *   Bit 01 : OnlyViaBadge
   *   Bit 02 : RemoteAccess
   *   Bit 03 : OnlyViaTelemax
   *   Bit 04 : ForceBackHome
   *   Bit 05 : CanChgSalle
   *   Bit 06 : GotoFirstOnglet
   *   Bit 07 : StayInAccueil
   *   Bit 08 : AllLastSalle
   *   Bit 09 : ModePOS
   *   Bit 10 : Manager
   *   Bit 11 : SuperStaffAutomatic
   *   Bit 12 : ManagerPasDeCaisse
   *   Bit 13 : StudentUseTeacherOnlyDivisions
   *   Bit 14 : StudentUseTeacherOnlyStations
   *   Bit 15 : StudentUseTeacherOnlyOnglets
   *   Bit 16 : GotoLastTbl
   *   Bit 17 : OpenStaff_DoNotPrintRpt
   *   Bit 20 : OpenService
   *   Bit 21 : OpenService_NoDteControl
   *   Bit 24 : ClotureService
   *   Bit 25 : ClotureService_WithOpenTable
   *   Bit 26 : ClotureService_PrintRpt
   *   Bit 30 : ClotureStaff
   *   Bit 31 : ClotureStaff_WithOpenTable
   *   Bit 32 : ClotureStaff_DoNotPrintRpt
   *   Bit 33 : ClotureStaff_DoNotKeepPrestation
   *   Bit 34 : ReOpenStaff
   *   Bit 40 : Visu
   *   Bit 41 : VisuTjsFiltree
   *   Bit 42 : VisuSansTotaux
   *   Bit 43 : VisuRptXorZ
   *   Bit 44 : VisuShowDate
   *   Bit 50 : ModifBlocage
   *   Bit 51 : ModifStock
   *   Bit 52 : WebView
   *   Bit 60 : Boss
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Staff Pointage Flags
   *   Bit 01 : CanPrintFullTicket
   *   Bit 02 : CanPointer
   *   Bit 03 : NoBtnError
   *   Bit 04 : AnnuleArticle
   *   Bit 05 : AnnuleControlee
   *   Bit 06 : ShowBtnRemise
   *   Bit 07 : ShowBtnChgPrix
   *   Bit 08 : ShowBtnOffert
   *   Bit 09 : CanToggleInOut
   *   Bit 10 : Training
   *   Bit 11 : ForceTraining
   *   Bit 12 : OnlyTraining
   *   Bit 15 : CanToggleTariff
   *   Bit 20 : CanAddition
   *   Bit 21 : RedoAddition
   *   Bit 22 : CanPointerAfterAdd
   *   Bit 23 : ParamAddition
   *   Bit 30 : CanCash
   *   Bit 31 : ManualCashDrawer
   *   Bit 32 : NoCashDrawer
   *   Bit 33 : NoAutoCashDrawer
   *   Bit 34 : NoAutoCashDrawerIfConso
   *   Bit 35 : CanSplitMontant
   *   Bit 36 : NoNegatifOnMachine
   *   Bit 40 : Split
   *   Bit 41 : SplitAfterAddition
   *   Bit 51 : TftAfterAddition
   */
  @JsonKey(defaultValue: 0)
  final num PointageFlags;

  /** Staff Backoffice Flags
   *   Bit 10 : EditStaff
   *   Bit 11 : EditStaffLimited
   *   Bit 13 : EditStaffSuperLimited
   *   Bit 14 : EditStaffViewAll
   *   Bit 20 : EditMsgAccueil
   *   Bit 21 : EditPlanSalle
   *   Bit 22 : EditCarte
   *   Bit 23 : EditModePayement
   *   Bit 24 : EditImprimantes
   *   Bit 25 : EditImages
   *   Bit 40 : EditEvenement
   *   Bit 41 : EditReservation
   *   Bit 63 : EditOthers
   */
  @JsonKey(defaultValue: 0)
  final num BOFlags;

  /** Staff Olap Flags
   *   Bit 10 : DTSOps
   *   Bit 11 : DTS_NoArchives
   *   Bit 12 : DTS_NoDBOps
   *   Bit 13 : DTS_NoExportImportOps
   *   Bit 20 : SQLEditor
   *   Bit 21 : SQLBtns
   *   Bit 28 : Tools
   *   Bit 34 : DuplicataAdd
   *   Bit 35 : TicketSimple
   *   Bit 36 : RefundTicket
   *   Bit 40 : AccLink
   *   Bit 41 : AccLinkParams
   *   Bit 50 : Billing
   */
  @JsonKey(defaultValue: 0)
  final num OLAPFlags;

  /** Staff Report Flags
   *   Bit 01 : RptPrint
   *   Bit 02 : RptFiltered
   *   Bit 10 : RptStatis
   *   Bit 11 : RptListeReassor
   *   Bit 12 : RptTablesOuvertes
   *   Bit 13 : RptCustom1
   *   Bit 16 : RptStaffOuverts
   *   Bit 17 : RptCustom2
   *   Bit 19 : RptRptJournee
   *   Bit 21 : RptCustom3
   *   Bit 22 : RptTaxRate
   *   Bit 23 : RptDetailsModif
   *   Bit 25 : RptCustom4
   *   Bit 26 : RptFR3SummaryView
   *   Bit 27 : RptPointages
   *   Bit 29 : RptCustom5
   *   Bit 30 : RptFR3Renta
   *   Bit 31 : RptRecettes
   *   Bit 32 : RptDuplicClotureStaff
   *   Bit 33 : RptCustom6
   *   Bit 34 : RptFR3DailyView
   *   Bit 35 : RptAdditions
   *   Bit 36 : RptDuplicClotureService
   *   Bit 37 : RptVerifTVA
   *   Bit 38 : RptExtRpts
   *   Bit 39 : RptAdditionsDet
   *   Bit 40 : RptSrvcZ
   *   Bit 41 : RptAll
   *   Bit 50 : RptExtRptsEdit
   */
  @JsonKey(defaultValue: 0)
  final num RptFlags;

  /** Staff Report Flags
   *   Bit 00 : MemberCreation
   *   Bit 01 : MemberDelete
   *   Bit 02 : MemberModif
   *   Bit 10 : MemberModifTVA
   *   Bit 11 : MemberModifCreditLimit
   *   Bit 13 : MemberModifDiscount
   *   Bit 14 : MemberModifAddress
   *   Bit 15 : MemberModifContact
   *   Bit 16 : MemberModifMemo
   *   Bit 30 : MemberVoirTVA
   *   Bit 31 : MemberVoirCreditLimit
   *   Bit 33 : MemberVoirDiscount
   *   Bit 34 : MemberVoirAddress
   *   Bit 35 : MemberVoirContact
   *   Bit 36 : MemberVoirMemo
   *   Bit 40 : MemberShowBtn
   *   Bit 41 : MemberNoSelect
   *   Bit 42 : MemberSelectOnlyBarcode
   *   Bit 50 : MemberEncaisseSurCpte
   *   Bit 51 : MemberRechargeCpte
   *   Bit 52 : MemberCaution
   *   Bit 53 : MemberEncaisseSurCpteLimited
   *   Bit 58 : MemberSoloCloture
   */
  @JsonKey(defaultValue: 0)
  final num MemberFlags;
  @JsonKey(defaultValue: '')
  final String TblModePOS;

  /** Print Layout */
  @JsonKey(defaultValue: 0)
  final num LayoutRptOuv;

  /** Accessible Division(s) for the Station,Staff,Article,.. */
  @JsonKey(defaultValue: '')
  final String Divisions;

  /** Accessible Station(s) for the Staff,Article,.. */
  @JsonKey(defaultValue: '')
  final String Stations;

  /** Visible Tab(s) for the Station,Staff,... */
  @JsonKey(defaultValue: '')
  final String Onglets;
  @JsonKey(defaultValue: '')
  final String StaffIN;
  @JsonKey(defaultValue: '')
  final String StaffOUT;
  @JsonKey(defaultValue: '')
  final String ClockIN;
  @JsonKey(defaultValue: '')
  final String ClockOUT;
  @JsonKey(defaultValue: 0)
  final num SaldoOuv;
  @JsonKey(defaultValue: 0)
  final num ConsoOuv;
  @JsonKey(defaultValue: 0)
  final num CvtsOuv;
  @JsonKey(defaultValue: '')
  final String LstSalle;

  /**
   *
   * Mix Flags and PointageFlags [sfOnlyClockInOut,sfCommis,sfManager,sfBoss]   */
  @JsonKey(defaultValue: 0)
  final int StaffLevel;
}
